@@ -74,7 +74,7 @@ class MapfwBenchmarker:
                         except FunctionTimedOut:
                             sol = None
                         except Exception as e:
-                            print("ERROR: "+e)
+                            print(f"ERROR: {e}")
                         return sol
                 else:
                     def solve_func(problem):
